@@ -12,7 +12,7 @@ if os.name == "nt":
 @attr.s
 class Token(object):
     """
-    The object that models a token (a string of chars between two spaces/punct.
+    The object that models a token (a string of chars between two spaces/punct).
 
     Attributes:
             text (str): string representation of the Token
@@ -33,13 +33,13 @@ class Token(object):
     def bio_label(self):
         return self.label.split("-")[0]
 
-    def has_outside_label(self) -> bool:
+    def is_outside_label(self) -> bool:
         return self.bio_label == "O"
 
-    def has_begin_label(self) -> bool:
+    def is_begin_label(self) -> bool:
         return self.bio_label == "B"
 
-    def has_inside_label(self) -> bool:
+    def is_inside_label(self) -> bool:
         return self.bio_label == "I"
 
 
@@ -64,4 +64,4 @@ class Token(object):
 
         """
 
-        return {"text": self.text, "label": self.label, "prob": self.probability}
+        return {"text": self.text, "label": self.label, "probability": self.probability}
