@@ -993,7 +993,7 @@ def fuse_spans(output_tokens: List[Token]) -> List[Borrowing]:
     start_pos = 0
 
     for i, token in enumerate(output_tokens):
-        if token.has_outside_label():
+        if token.is_outside_label():
             if half_boiled_label:
                 bor = Borrowing.from_span(half_boiled_token, half_boiled_label, start_pos, i,
                                    output_tokens)
@@ -1002,14 +1002,14 @@ def fuse_spans(output_tokens: List[Token]) -> List[Borrowing]:
                 half_boiled_token = []
             start_pos = i
             #new_output.append((token, label))
-        if token.has_begin_label():
+        if token.is_begin_label():
             if half_boiled_label:
                 bor = Borrowing.from_span(half_boiled_token, half_boiled_label, start_pos, i, output_tokens)
                 new_output.append(bor)
             half_boiled_label = token.lang_label
             half_boiled_token = [token]
             start_pos = i
-        if token.has_inside_label():
+        if token.is_inside_label():
             half_boiled_label = token.lang_label
             if not half_boiled_token:
                 start_pos = i
